@@ -28,6 +28,8 @@
 #include "kerfuffle_export.h"
 #include "archiveinterface.h"
 #include "archive.h"
+#include "queries.h"
+#include "observer.h"
 
 #include <KJob>
 #include <QList>
@@ -41,87 +43,102 @@ namespace ThreadWeaver
 
 namespace Kerfuffle
 {
-	class KERFUFFLE_EXPORT ListJob: public KJob
+	class KERFUFFLE_EXPORT Job: public KJob, public ArchiveObserver
+	{
+		Q_OBJECT
+		//we friend the Archive class to let it create jobs
+		friend class Archive;
+
+		public:
+			void start();
+
+			//abstract implemented methods from observer
+			virtual void onError( const QString & message, const QString & details );
+			virtual void onInfo( const QString & info);
+			virtual void onEntry( const ArchiveEntry & archiveEntry );
+			virtual void onProgress( double );
+			virtual void onEntryRemoved( const QString & path );
+
+		public slots:
+			virtual void doWork() = 0;
+
+		signals:
+			void userQuery( Query* );
+			void newEntry( const ArchiveEntry & );
+			void error( const QString& errorMessage, const QString& details );
+			void entryRemoved( const QString & entry );
+
+		protected:
+			Job(ReadOnlyArchiveInterface *interface, QObject *parent = 0);
+			ReadOnlyArchiveInterface* m_interface;
+
+	};
+
+	class KERFUFFLE_EXPORT ListJob: public Job
 	{
 		Q_OBJECT
 		public:
 			explicit ListJob( ReadOnlyArchiveInterface *interface, QObject *parent = 0 );
 
-			void start();
-
-		signals:
-			void newEntry( const ArchiveEntry & );
-			void error( const QString& errorMessage, const QString& details );
+			void doWork();
+			bool isSingleFolderArchive() { return m_isSingleFolderArchive; }
+			bool isPasswordProtected() { return m_isPasswordProtected; }
+			QString subfolderName() { return m_subfolderName; }
+			qlonglong extractedFilesSize() { return m_extractedFilesSize; }
 
 		private slots:
-			void done( ThreadWeaver::Job* );
-			void progress( double );
+			void onNewEntry(const ArchiveEntry&);
 
 		private:
-			ReadOnlyArchiveInterface *m_archive;
+			bool m_isSingleFolderArchive;
+			bool m_isPasswordProtected;
+			QString m_subfolderName;
+			QString m_previousEntry;
+			qlonglong m_extractedFilesSize;
 	};
 
-	class KERFUFFLE_EXPORT ExtractJob: public KJob
+	class KERFUFFLE_EXPORT ExtractJob: public Job
 	{
 		Q_OBJECT
 		public:
-			ExtractJob( const QList<QVariant> & files, const QString& destinationDir, bool preservePaths, ReadOnlyArchiveInterface *interface, QObject *parent = 0 );
+			ExtractJob( const QList<QVariant> & files, const QString&
+					destinationDir, ExtractionOptions options,
+					ReadOnlyArchiveInterface *interface, QObject *parent = 0 );
 
-			void start();
-
-		private slots:
-			void done( ThreadWeaver::Job * );
-			void progress( double );
-			void error( const QString&, const QString& );
+			void doWork();
 
 		private:
+			void fillInDefaultValues(ExtractionOptions& options);
 			QList<QVariant>           m_files;
 			QString                   m_destinationDir;
-			bool                      m_preservePaths;
-			ReadOnlyArchiveInterface *m_archive;
+			ExtractionOptions m_options;
 	};
 
-	class KERFUFFLE_EXPORT AddJob: public KJob
+	class KERFUFFLE_EXPORT AddJob: public Job
 	{
 		Q_OBJECT
 		public:
-			AddJob( const QStringList & files, ReadWriteArchiveInterface *interface, QObject *parent = 0 );
-
-			void start();
-
-		signals:
-			void newEntry( const ArchiveEntry & );
-
-		private slots:
-			void done( ThreadWeaver::Job * );
-			void progress( double );
-			void error( const QString&, const QString& );
+			AddJob(const QStringList & files, const CompressionOptions& options,
+					ReadWriteArchiveInterface *interface, QObject *parent = 0
+					);
+			void doWork();
 
 		private:
 			QStringList                m_files;
-			ReadWriteArchiveInterface *m_archive;
+			CompressionOptions m_options;
 
 	};
 
-	class KERFUFFLE_EXPORT DeleteJob: public KJob
+	class KERFUFFLE_EXPORT DeleteJob: public Job
 	{
 		Q_OBJECT
 		public:
-			DeleteJob( const QList<QVariant>& files, ReadWriteArchiveInterface *interface, QObject *parent = 0 );
-
-			void start();
-
-		signals:
-			void entryRemoved( const QString & entry );
-			void error( const QString& errorMessage, const QString& details );
-
-		private slots:
-			void done( ThreadWeaver::Job * );
-			void progress( double );
+			DeleteJob( const QList<QVariant>& files, ReadWriteArchiveInterface
+					*interface, QObject *parent = 0 );
+			void doWork();
 
 		private:
 			QList<QVariant>            m_files;
-			ReadWriteArchiveInterface *m_archive;
 	};
 } // namespace Kerfuffle
 
