@@ -24,6 +24,7 @@
 #include <QAbstractItemModel>
 #include <kjobtrackerinterface.h>
 #include "kerfuffle/archive.h"
+#include "kerfuffle/queries.h"
 
 class ArchiveNode;
 class ArchiveDirNode;
@@ -47,29 +48,38 @@ class ArchiveModel: public QAbstractItemModel
 		int rowCount( const QModelIndex &parent = QModelIndex() ) const;
 		int columnCount( const QModelIndex &parent = QModelIndex() ) const;
 
-		void setArchive( Kerfuffle::Archive *archive );
+		//drag and drop related
+		virtual Qt::DropActions supportedDropActions () const;
+		virtual QStringList mimeTypes () const;
+		virtual QMimeData * mimeData ( const QModelIndexList & indexes ) const;
+
+		virtual bool dropMimeData ( const QMimeData * data, Qt::DropAction action, int row, int column, const QModelIndex & parent );
+
+
+		KJob* setArchive( Kerfuffle::Archive *archive );
 		Kerfuffle::Archive *archive() const { return m_archive; }
 
 		ArchiveEntry entryForIndex( const QModelIndex &index );
 		int childCount( const QModelIndex &index );
 
-		ExtractJob* extractFile( const QVariant& fileName, const QString & destinationDir, bool preservePaths = false );
-		ExtractJob* extractFiles( const QList<QVariant>& files, const QString & destinationDir, bool preservePaths = false );
+		ExtractJob* extractFile( const QVariant& fileName, const QString & destinationDir, ExtractionOptions options = ExtractionOptions()) const;
+		ExtractJob* extractFiles( const QList<QVariant>& files, const QString & destinationDir, const Kerfuffle::ExtractionOptions options = ExtractionOptions()	) const;
 
-		AddJob* addFiles( const QStringList & paths );
+		AddJob* addFiles( const QStringList & paths, const CompressionOptions& options = CompressionOptions() );
 		DeleteJob* deleteFiles( const QList<QVariant> & files );
 
-		void setJobTracker( KJobTrackerInterface *tracker ) { m_jobTracker = tracker; }
-
 	signals:
 		void loadingStarted();
-		void loadingFinished();
+		void loadingFinished(KJob *);
 		void extractionFinished( bool success );
 		void error( const QString& error, const QString& details );
+		void droppedFiles(const QStringList& files, const QString& path = QString());
 
 	private slots:
 		void slotNewEntry( const ArchiveEntry& entry );
 		void slotEntryRemoved( const QString & path );
+		void slotUserQuery(Query *query);
+		void slotCleanupEmptyDirs();
 
 	private:
 		ArchiveDirNode* parentFor( const ArchiveEntry& entry );
@@ -80,6 +90,7 @@ class ArchiveModel: public QAbstractItemModel
 		 */
 		void insertNode( ArchiveNode *node );
 
+		QList<int> m_showColumns;
 		Kerfuffle::Archive *m_archive;
 		ArchiveDirNode *m_rootNode;
 		KJobTrackerInterface *m_jobTracker;
