@@ -21,7 +21,6 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-
 #ifndef __DISKLIST_H__
 #define __DISKLIST_H__
 
@@ -31,7 +30,9 @@
 //#include <kcontrol.h>
 
 // defines the os-type
-#include <qglobal.h>
+#include <QtCore/qglobal.h>
+//Added by qt3to4:
+#include <Qt3Support/Q3PtrList>
 
 #include "disks.h"
 
@@ -55,14 +56,16 @@
 #define SEPARATOR "|"
 
 /***************************************************************************/
-typedef QPtrList<DiskEntry>		DisksBase;
-typedef QPtrListIterator<DiskEntry>	DisksIterator;
+typedef Q3PtrList<DiskEntry>		DisksBase;
+typedef Q3PtrListIterator<DiskEntry>	DisksIterator;
+
+class KProcess;
 
 /***************************************************************************/
 class Disks : public DisksBase
 {
  public:
-  Disks(bool deepCopies=TRUE) { dc = deepCopies;}
+  Disks(bool deepCopies=true) { dc = deepCopies;}
   ~Disks() { clear(); }
 private:
   int compareItems( DiskEntry s1, DiskEntry s2 )
@@ -73,7 +76,7 @@ private:
       ret = s1.mountPoint().compare(s2.mountPoint());
     }
 
-    kdDebug() << "compareDISKS " << s1.deviceName() << " vs " << s2.deviceName() << " (" << ret << ")" << endl;
+    kDebug() << "compareDISKS " << s1.deviceName() << " vs " << s2.deviceName() << " (" << ret << ")" ;
     return( ret );
   }
 
@@ -96,7 +99,7 @@ private:
 class DiskList : public QObject
 {  Q_OBJECT
 public:
-   DiskList( QObject *parent=0, const char *name=0 );
+   DiskList( QObject *parent=0 );
  ~DiskList();
    int readFSTAB();
    int readDF();
@@ -118,7 +121,6 @@ public slots:
   void applySettings();
 
 private slots:
-   void receivedDFStdErrOut(KProcess *, char *data, int len);
    void dfDone();
 
 private:
@@ -126,9 +128,8 @@ private:
 
   Disks            *disks;
   KProcess         *dfProc;
-  QString           dfStringErrOut;
   bool              readingDFStdErrOut;
-  KConfig           *config;
+  KSharedConfigPtr  config;
   bool              updatesDisabled;
   
 };
