@@ -17,20 +17,20 @@
  *
  */
 
-#ifndef _OPTION_DIALOG_H_
-#define _OPTION_DIALOG_H_
+#ifndef OPTIONDIALOG_H
+#define OPTIONDIALOG_H
 
-#include <kdialogbase.h>
+#include <kpagedialog.h>
 
 class KDFConfigWidget;
 class MntConfigWidget;
 
-class COptionDialog : public KDialogBase
+class COptionDialog : public KPageDialog
 {
   Q_OBJECT
 
   public:
-    COptionDialog( QWidget *parent=0, const char *name=0, bool modal=true );
+    explicit COptionDialog( QWidget *parent=0 );
     ~COptionDialog( void );
 
   protected slots:
