@@ -36,6 +36,9 @@
 #include "kgpginterface.h"
 #include "convert.h"
 #include "images.h"
+#include "kgpgchangekey.h"
+#include "kgpgchangepass.h"
+#include "kgpgitemnode.h"
 
 using namespace KgpgCore;
 
@@ -92,7 +95,7 @@ void KgpgTrustLabel::change()
     m_color_w->setPalette(palette);
 }
 
-KgpgDateDialog::KgpgDateDialog(QWidget *parent, const bool &unlimited, QDate date)
+KgpgDateDialog::KgpgDateDialog(QWidget *parent, QDate date)
               : KDialog(parent)
 {
     setCaption(i18n("Choose New Expiration"));
@@ -103,12 +106,11 @@ KgpgDateDialog::KgpgDateDialog(QWidget *parent, const bool &unlimited, QDate dat
     QWidget *page = new QWidget(this);
     m_unlimited = new QCheckBox(i18nc("Key has unlimited lifetime", "Unlimited"), page);
 
-    if (unlimited)
+    if (date.isNull())
         date = QDate::currentDate();
 
     m_datepicker = new KDatePicker(date, page);
-    if (unlimited)
-    {
+    if (date.isNull()) {
         m_datepicker->setEnabled(false);
         m_unlimited->setChecked(true);
     }
@@ -128,12 +130,10 @@ KgpgDateDialog::KgpgDateDialog(QWidget *parent, const bool &unlimited, QDate dat
 
 QDate KgpgDateDialog::date() const
 {
-    return m_datepicker->date();
-}
-
-bool KgpgDateDialog::unlimited() const
-{
-    return m_unlimited->isChecked();
+    if (m_unlimited->isChecked())
+        return QDate();
+    else
+        return m_datepicker->date();
 }
 
 void KgpgDateDialog::slotCheckDate(const QDate &date)
@@ -143,28 +143,40 @@ void KgpgDateDialog::slotCheckDate(const QDate &date)
 
 void KgpgDateDialog::slotEnableDate(const bool &ison)
 {
+    m_datepicker->setEnabled(!ison);
     if (ison)
-    {
-        m_datepicker->setEnabled(false);
         enableButtonOk(true);
-    }
     else
-    {
-        m_datepicker->setEnabled(true);
-        enableButtonOk(m_datepicker->date() >= QDate::currentDate());
-    }
+        slotCheckDate(m_datepicker->date());
+}
+
+KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, QWidget *parent)
+           : KDialog(parent), keychange(new KGpgChangeKey(node))
+{
+    m_node = node;
+    m_key = node->getKey();
+    init();
 }
 
 KgpgKeyInfo::KgpgKeyInfo(KgpgCore::KgpgKey *key, QWidget *parent)
-           : KDialog(parent)
+           : KDialog(parent), keychange(new KGpgChangeKey(key))
 {
-    setButtons(Close);
-    setDefaultButton(Close);
-    setModal(true);
-
+    m_node = NULL;
     m_key = key;
+    init();
+}
+
+void KgpgKeyInfo::init()
+{
+    setButtons(Ok | Apply | Cancel);
+    setDefaultButton(Ok);
+    setModal(true);
+    enableButtonApply(false);
+
     m_keywaschanged = false;
 
+    m_changepass = NULL;
+
     QWidget *page = new QWidget(this);
     QWidget *top = new QWidget(page);
     QWidget *right = new QWidget(top);
@@ -197,7 +209,10 @@ KgpgKeyInfo::KgpgKeyInfo(KgpgCore::KgpgKey *key, QWidget *parent)
     connect(m_owtrust, SIGNAL(activated(int)), this, SLOT(slotChangeTrust(int)));
     connect(m_photoid, SIGNAL(activated (const QString &)), this, SLOT(slotLoadPhoto(const QString &)));
     connect(m_email, SIGNAL(leftClickedUrl(const QString &)), this, SLOT(slotOpenUrl(const QString &)));
-    connect(this, SIGNAL(closeClicked()), this, SLOT(slotPreOk()));
+    connect(this, SIGNAL(okClicked()), this, SLOT(slotPreOk()));
+    connect(this, SIGNAL(cancelClicked()), this, SLOT(slotPreCancel()));
+    connect(this, SIGNAL(applyClicked()), SLOT(slotApply()));
+    connect(keychange, SIGNAL(done(int)), SLOT(slotApplied(int)));
 
     displayKey();
     if (!m_hasphoto)
@@ -208,7 +223,11 @@ KgpgKeyInfo::KgpgKeyInfo(KgpgCore::KgpgKey *key, QWidget *parent)
 
 KgpgKeyInfo::~KgpgKeyInfo()
 {
-	delete m_key;
+	if (keychange)
+		keychange->selfdestruct(false);
+	if (!m_node)
+		delete m_key;
+	delete m_changepass;
 }
 
 QGroupBox* KgpgKeyInfo::_keypropertiesGroup(QWidget *parent)
@@ -371,34 +390,21 @@ QGroupBox* KgpgKeyInfo::_fingerprintGroup(QWidget *parent)
     return group;
 }
 
-void KgpgKeyInfo::reloadKey(KgpgInterface *interface)
+void KgpgKeyInfo::reloadKey()
 {
-    KgpgKeyList listkeys = interface->readPublicKeys(true, m_key->fullId());
-    interface->deleteLater();
+	KgpgInterface *interface = new KgpgInterface();
+	KgpgKeyList listkeys = interface->readPublicKeys(true, m_key->fullId());
+	delete interface;
 
-    Q_ASSERT(listkeys.count() > 0);
+	Q_ASSERT(listkeys.count() > 0);
 
-    delete m_key;
-    m_key = new KgpgKey(listkeys.at(0));
-    displayKey();
+	delete m_key;
+	m_key = new KgpgKey(listkeys.at(0));
+	displayKey();
 }
 
 void KgpgKeyInfo::displayKey()
 {
-    KgpgKeySub subkey;
-
-    // Get the first encryption subkey
-    KgpgKeySubListPtr sublist = m_key->subList();
-    for (int i = 0; i < sublist->count(); ++i)
-    {
-        KgpgKeySub temp = sublist->at(i);
-        if (temp.type() == SKT_ENCRYPTION)
-        {
-            subkey = temp;
-            break;
-        }
-    }
-
     QString name = m_key->name();
     setCaption(name);
     m_name->setText("<qt><b>" + name + "</b></qt>");
@@ -411,7 +417,7 @@ void KgpgKeyInfo::displayKey()
     else
     {
         m_email->setText("<qt><b>&lt;" + m_key->email() + "&gt;</b></qt>");
-        m_email->setUrl("mailto:" + name + "<" + m_key->email() + ">");
+        m_email->setUrl("mailto:" + name + '<' + m_key->email() + '>');
     }
 
     KgpgKeyTrust keytrust = m_key->valid() ? m_key->trust() : TRUST_DISABLED;
@@ -419,13 +425,13 @@ void KgpgKeyInfo::displayKey()
     QColor trustcolor = Convert::toColor(keytrust);
 
     m_id->setText(m_key->fullId());
-    m_algorithm->setText(Convert::toString(m_key->algorithm()) + " / " + Convert::toString(subkey.algorithm()));
+    m_algorithm->setText(Convert::toString(m_key->algorithm()) + " / " + Convert::toString(m_key->encryptionAlgorithm()));
     m_algorithm->setWhatsThis("<qt>The left part is the algorithm used by the <b>signature</b> key. The right part is the algorithm used by the <b>encryption</b> key.</qt>");
     m_creation->setText(m_key->creation());
     m_expiration->setText(m_key->expiration());
     m_trust->setText(tr);
     m_trust->setColor(trustcolor);
-    m_length->setText(QString::number(m_key->size()) + " / " + QString::number(subkey.size()));
+    m_length->setText(QString::number(m_key->size()) + " / " + QString::number(m_key->encryptionSize()));
     m_length->setWhatsThis("<qt>The left part is the size of the <b>signature</b> key. The right part is the size of the <b>encryption</b> key.</qt>");
     m_fingerprint->setText(m_key->fingerprintBeautified());
 
@@ -474,8 +480,6 @@ void KgpgKeyInfo::displayKey()
 
     if (!m_key->valid())
         m_disable->setChecked(true);
-
-    m_isunlimited = m_key->unlimited();
 }
 
 void KgpgKeyInfo::slotOpenUrl(const QString &url) const
@@ -501,98 +505,61 @@ void KgpgKeyInfo::slotSetPhoto(const QPixmap &pixmap, KgpgInterface *interface)
 
 void KgpgKeyInfo::slotPreOk()
 {
-    if (m_keywaschanged)
-        emit keyNeedsRefresh(m_key->fullId());
-    accept();
+	if (m_keywaschanged && m_node)
+		emit keyNeedsRefresh(m_node);
+	keychange->selfdestruct(true);
+	keychange = NULL;
+	accept();
 }
 
 void KgpgKeyInfo::slotChangeDate()
 {
-    KgpgDateDialog *dialog = new KgpgDateDialog(this, m_isunlimited, m_key->expirationDate());
-    if (dialog->exec() == QDialog::Accepted)
-    {
-        setControlEnable(false);
-        KgpgInterface *process = new KgpgInterface();
-        connect(process, SIGNAL(keyExpireFinished(int, KgpgInterface*)), this, SLOT(slotInfoExpirationChanged(int, KgpgInterface*)));
-
-        if (dialog->unlimited())
-            process->keyExpire(m_key->fullId(), QDate());
-        else
-            process->keyExpire(m_key->fullId(), dialog->date());
-    }
-    delete dialog;
-}
-
-void KgpgKeyInfo::slotInfoExpirationChanged(const int &res, KgpgInterface *interface)
-{
-    if (res == 2)
-    {
-        m_keywaschanged = true;
-        reloadKey(interface);
-    }
-    else
-    if (res == 1)
-        KMessageBox::error(this, i18n("Could not change expiration"), i18n("Bad passphrase. Expiration of the key has not been changed."));
-
-    interface->deleteLater();
-    setControlEnable(true);
+	KgpgDateDialog *dialog = new KgpgDateDialog(this, m_key->expirationDate());
+	if (dialog->exec() == QDialog::Accepted) {
+		keychange->setExpiration(dialog->date());
+		enableButtonApply(keychange->wasChanged());
+	}
+	delete dialog;
 }
 
 void KgpgKeyInfo::slotDisableKey(const bool &ison)
 {
-    setControlEnable(false);
-    KgpgInterface *interface = new KgpgInterface;
-    connect (interface, SIGNAL(changeDisableFinished(KgpgInterface*, int)), this, SLOT(slotDisableKeyFinished(KgpgInterface*, int)));
-    interface->changeDisable(m_key->fullId(), ison);
-}
-
-void KgpgKeyInfo::slotDisableKeyFinished(KgpgInterface *interface, int res)
-{
-    if (res == 0)
-    {
-        reloadKey(interface);
-        m_keywaschanged = true;
-    }
-    setControlEnable(true);
+	keychange->setDisable(ison);
+	enableButtonApply(keychange->wasChanged());
 }
 
 void KgpgKeyInfo::slotChangePass()
 {
-    KgpgInterface *interface = new KgpgInterface();
-    connect(interface, SIGNAL(changePassFinished(int, KgpgInterface*)), this, SLOT(slotInfoPasswordChanged(int, KgpgInterface*)));
-    interface->changePass(m_key->fullId());
+	if (m_changepass == NULL) {
+		m_changepass = new KGpgChangePass(this, m_key->fingerprint());
+
+		connect(m_changepass, SIGNAL(done(int)), SLOT(slotInfoPasswordChanged(int)));
+	}
+
+	m_changepass->start();
+	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
 }
 
-void KgpgKeyInfo::slotInfoPasswordChanged(const int &res, KgpgInterface *interface)
+void KgpgKeyInfo::slotInfoPasswordChanged(const int &res)
 {
-    interface->deleteLater();
-
     if (res == 2)
         KPassivePopup::message(i18n("Passphrase for the key was changed"), QString(), Images::kgpg(), this);
     else if (res == 1)
         KMessageBox::error(this, i18n("Bad old passphrase, the passphrase for the key was not changed"), i18n("Could not change passphrase"));
+    QApplication::restoreOverrideCursor();
 }
 
 void KgpgKeyInfo::slotChangeTrust(const int &newtrust)
 {
-    setControlEnable(false);
-    KgpgInterface *interface = new KgpgInterface();
-    connect(interface, SIGNAL(changeTrustFinished(KgpgInterface*)), this, SLOT(slotInfoTrustChanged(KgpgInterface*)));
-    interface->changeTrust(m_key->fullId(), KgpgKeyOwnerTrust(newtrust + 1));
-}
-
-void KgpgKeyInfo::slotInfoTrustChanged(KgpgInterface *interface)
-{
-    m_keywaschanged = true;
-    reloadKey(interface);
-    setControlEnable(true);
-    m_owtrust->setFocus();
+	keychange->setOwTrust(KgpgKeyOwnerTrust(newtrust + 1));
+	enableButtonApply(keychange->wasChanged());
 }
 
 void KgpgKeyInfo::setControlEnable(const bool &b)
 {
     m_owtrust->setEnabled(b);
     m_disable->setEnabled(b);
+    enableButtonApply(b && keychange->wasChanged());
 
     if (m_expirationbtn)
         m_expirationbtn->setEnabled(b);
@@ -605,4 +572,28 @@ void KgpgKeyInfo::setControlEnable(const bool &b)
         QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
 }
 
+void KgpgKeyInfo::slotApply()
+{
+	setControlEnable(false);
+	keychange->apply();
+}
+
+void KgpgKeyInfo::slotApplied(int result)
+{
+	if (result) {
+		KMessageBox::error(this, i18n("Changing key properties failed."), i18n("Key properties"));
+	} else {
+		m_keywaschanged = true;
+		reloadKey();
+	}
+	setControlEnable(true);
+}
+
+void KgpgKeyInfo::slotPreCancel()
+{
+	if (m_keywaschanged && m_node)
+		emit keyNeedsRefresh(m_node);
+	reject();
+}
+
 #include "keyinfodialog.moc"
