@@ -463,14 +463,15 @@ void KeyServer::slotOk()
 
 QStringList KeyServer::getServerList()
 {
-    KConfig config("kgpgrc", KConfig::SimpleConfig);
-    KConfigGroup group = config.group("Servers");
+	QStringList serverList = KGpgSettings::keyServers(); // From kgpg config
+	if (!serverList.isEmpty()) {
+		serverList.replaceInStrings(QRegExp(" .*"), "");     // Remove kde 3.5 (Default) tag.
+		QString defaultServer = serverList.takeFirst();
+		qSort(serverList);
+		serverList.prepend(defaultServer);
+	}
 
-    QStringList serverlist;
-    serverlist << KgpgInterface::getGpgSetting("keyserver", KGpgSettings::gpgConfigPath());     // From gpg config
-    serverlist << group.readEntry("Server_List").split(',', QString::SkipEmptyParts);           // From kgpg config
-
-    return serverlist;
+	return serverList;
 }
 
 void KeyServer::handleQuit()
