@@ -25,14 +25,12 @@
 #include <KShortcut>
 #include <KUrl>
 
-#include "ui_kgpgwizard.h"
-
 class QDragEnterEvent;
 class QDropEvent;
 class QMenu;
 
 class KPassivePopup;
-class KgpgWizard;
+class KGpgFirstAssistant;
 class KAboutData;
 class KTemporaryFile;
 class KAction;
@@ -41,23 +39,16 @@ class KgpgSelectPublicKeyDlg;
 class KGpgTextInterface;
 class KeysManager;
 class KgpgLibrary;
+class KGpgItemModel;
+class KgpgInterface;
 
-class KgpgWizard : public Q3Wizard, public Ui::KgpgWizard
-{
-public:
-    KgpgWizard(QWidget *parent = 0) : Q3Wizard(parent)
-    {
-        setupUi(this);
-    }
-};
-
-class MyView : public QObject
+class KGpgUserActions : public QObject
 {
     Q_OBJECT
 
 public:
-    explicit MyView(QWidget *parent = 0, KSystemTrayIcon *parentTrayIcon = 0);
-    ~MyView();
+    KGpgUserActions(QWidget *parent, KSystemTrayIcon *parentTrayIcon, KGpgItemModel *model);
+    ~KGpgUserActions();
 
     KUrl droppedUrl;
     KUrl::List droppedUrls;
@@ -106,9 +97,8 @@ private:
 
     QMenu *droppopup;
     QMenu *udroppopup;
-    KAboutData *_aboutData;
     QStringList customDecrypt;
-    KgpgWizard *wiz;
+    KGpgFirstAssistant *m_assistant;
     KPassivePopup *pop;
     KTemporaryFile *kgpgFolderExtract;
     int compressionScheme;
@@ -116,17 +106,17 @@ private:
     KgpgSelectPublicKeyDlg *dialog;
     QClipboard::Mode clipboardMode;
     KSystemTrayIcon *trayIcon;
+    KGpgItemModel *m_model;
 
-    int startWizard();
-    int firstRun();
+    void startAssistant();
+    void firstRun();
 
     KUrl::List m_decryptionFailed;
+    QWidget *m_parentWidget;
 
 private slots:
-    void slotWizardClose();
-    void slotWizardChange();
+    void slotAssistantClose();
     void slotSaveOptionsPath();
-    void slotGenKey();
     void importSignature(const QString &ID);
     void slotSetClip(const QString &newtxt);
     void slotPassiveClip();
@@ -136,10 +126,11 @@ private slots:
     void readOptions();
     void droppedfile(KUrl::List);
     void droppedtext(const QString &inputText, bool allowEncrypt = true);
-    void unArchive();
     void slotSetCompression(int cp);
     void decryptNextFile(KgpgLibrary *lib, const KUrl &failed);
     void decryptFile(KgpgLibrary *lib);
+    void slotImportedKeys(KgpgInterface *iface, const QStringList &);
+    void slotImportedKeys(KgpgLibrary *lib, const QStringList &);
 };
 
 class kgpgapplet : public KSystemTrayIcon
@@ -147,9 +138,9 @@ class kgpgapplet : public KSystemTrayIcon
     Q_OBJECT
 
 public:
-    kgpgapplet(QWidget *parent = 0);
+    kgpgapplet(QWidget *parent, KGpgItemModel *model);
     ~kgpgapplet();
-    MyView *w;
+    KGpgUserActions *w;
 
 private:
     KSystemTrayIcon *kgpgapp;
@@ -185,7 +176,7 @@ private:
 
 private slots:
     void slotHandleQuit();
-    void wizardOver(const QString &defaultKeyId);
+    void assistantOver(const QString &defaultKeyId);
 };
 
 #endif // KGPGAPPLET_H
