@@ -17,9 +17,9 @@
 
 #include "kgpginterface.h"
 
+#include <QDir>
 #include <QTextStream>
 #include <QFile>
-#include <QDir>
 
 #include <kio/netaccess.h>
 #include <KMessageBox>
@@ -30,10 +30,10 @@
 #include <KConfig>
 #include <KDebug>
 #include <KGlobal>
+#include <KStandardDirs>
 #include <KUrl>
 
 #include "detailedconsole.h"
-#include "emailvalidator.h"
 #include "kgpgsettings.h"
 #include "convert.h"
 #include "gpgproc.h"
@@ -91,31 +91,96 @@ QString KgpgInterface::checkForUtf8bis(QString txt)
     return txt;
 }
 
-int KgpgInterface::gpgVersion()
+int KgpgInterface::gpgVersion(const QString &vstr)
 {
-    GPGProc process;
-    process << "--version";
-    process.start();
-    process.waitForFinished(-1);
+	if (vstr.isEmpty())
+		return -1;
 
-    if (process.exitCode() == 255)
-       return -1;
+	QStringList values = vstr.split('.');
+	if (values.count() < 3)
+		return -2;
 
-    QString line;
-    if (process.readln(line) != -1)
-        line = line.simplified().section(' ', -1);
+	return (0x10000 * values[0].toInt() + 0x100 * values[1].toInt() + values[2].toInt());
+}
 
-    QStringList values = line.split('.');
-    if (values.count() < 3)
-       return -2;
+QString KgpgInterface::gpgVersionString(const QString &binary)
+{
+	GPGProc process(0, binary);
+	process << "--version";
+	process.start();
+	process.waitForFinished(-1);
 
-    return (100 * values[0].toInt() + 10 * values[1].toInt() + values[2].toInt());
+	if (process.exitCode() == 255)
+		return QString();
+
+	QString line;
+	if (process.readln(line) != -1)
+		return line.simplified().section(' ', -1);
+	else
+		return QString();
+}
+
+QString KgpgInterface::getGpgProcessHome(const QString &binary)
+{
+	GPGProc process(0, binary);
+	process << "--version";
+	process.start();
+	process.waitForFinished(-1);
+
+	if (process.exitCode() == 255) {
+		return QString();
+	}
+
+	QString line;
+	while (process.readln(line) != -1) {
+		if (line.startsWith("Home: ")) {
+			line.remove(0, 6);
+			return line;
+		}
+	}
+
+	return QString();
+}
+
+QString KgpgInterface::getGpgHome(const QString &binary)
+{
+	// First try: if environment is set GnuPG will use that directory
+	// We can use this directly without starting a new process
+	QByteArray env = qgetenv("GNUPGHOME");
+	QString gpgHome;
+	if (!env.isEmpty()) {
+		gpgHome = env;
+	} else if (!binary.isEmpty()) {
+		// Second try: start GnuPG and ask what it is
+		gpgHome = getGpgProcessHome(binary);
+	}
+
+	// Third try: guess what it is.
+	if (gpgHome.isEmpty()) {
+#ifdef Q_OS_WIN32	//krazy:exclude=cpp
+		gpgHome = qgetenv("APPDATA") + "/gnupg/";
+		gpgHome.replace('\\', '/');
+#else
+		gpgHome = QDir::homePath() + "/.gnupg/";
+#endif
+	}
+
+	gpgHome.replace("//", "/");
+
+	if (!gpgHome.endsWith('/'))
+		gpgHome.append('/');
+
+	if (gpgHome.startsWith('~'))
+		gpgHome.replace(0, 1, QDir::homePath());
+
+	KStandardDirs::makeDir(gpgHome, 0700);
+	return gpgHome;
 }
 
 QStringList KgpgInterface::getGpgGroupNames(const QString &configfile)
 {
     QStringList groups;
-    QFile qfile(QFile::encodeName(configfile));
+    QFile qfile(configfile);
     if (qfile.open(QIODevice::ReadOnly) && (qfile.exists()))
     {
         QTextStream t(&qfile);
@@ -135,7 +200,7 @@ QStringList KgpgInterface::getGpgGroupNames(const QString &configfile)
 
 QStringList KgpgInterface::getGpgGroupSetting(const QString &name, const QString &configfile)
 {
-    QFile qfile(QFile::encodeName(configfile));
+    QFile qfile(configfile);
     if (qfile.open(QIODevice::ReadOnly) && (qfile.exists()))
     {
         QTextStream t(&qfile);
@@ -165,7 +230,7 @@ void KgpgInterface::setGpgGroupSetting(const QString &name, const QStringList &v
 {
     QString texttowrite;
     bool found = false;
-    QFile qfile(QFile::encodeName(configfile));
+    QFile qfile(configfile);
 
     kDebug(2100) << "Changing group: " << name ;
     if (qfile.open(QIODevice::ReadOnly) && (qfile.exists()))
@@ -206,7 +271,7 @@ void KgpgInterface::setGpgGroupSetting(const QString &name, const QStringList &v
 void KgpgInterface::delGpgGroup(const QString &name, const QString &configfile)
 {
     QString texttowrite;
-    QFile qfile(QFile::encodeName(configfile));
+    QFile qfile(configfile);
     if (qfile.open(QIODevice::ReadOnly) && (qfile.exists()))
     {
         QTextStream t(&qfile);
@@ -238,7 +303,7 @@ void KgpgInterface::delGpgGroup(const QString &name, const QString &configfile)
 QString KgpgInterface::getGpgSetting(QString name, const QString &configfile)
 {
     name = name.simplified() + ' ';
-    QFile qfile(QFile::encodeName(configfile));
+    QFile qfile(configfile);
     if (qfile.open(QIODevice::ReadOnly) && (qfile.exists()))
     {
         QTextStream t(&qfile);
@@ -264,7 +329,7 @@ void KgpgInterface::setGpgSetting(const QString &name, const QString &value, con
     QString temp = name + ' ';
     QString texttowrite;
     bool found = false;
-    QFile qfile(QFile::encodeName(url));
+    QFile qfile(url);
 
     if (qfile.open(QIODevice::ReadOnly) && (qfile.exists()))
     {
@@ -299,7 +364,7 @@ void KgpgInterface::setGpgSetting(const QString &name, const QString &value, con
 
 bool KgpgInterface::getGpgBoolSetting(const QString &name, const QString &configfile)
 {
-    QFile qfile(QFile::encodeName(configfile));
+    QFile qfile(configfile);
     if (qfile.open(QIODevice::ReadOnly) && (qfile.exists()))
     {
         QTextStream t(&qfile);
@@ -317,7 +382,7 @@ void KgpgInterface::setGpgBoolSetting(const QString &name, const bool &enable, c
 {
     QString texttowrite;
     bool found = false;
-    QFile qfile(QFile::encodeName(url));
+    QFile qfile(url);
 
     if (qfile.open(QIODevice::ReadOnly) && (qfile.exists()))
     {
@@ -785,6 +850,10 @@ void KgpgInterface::readSecretKeysProcess(GPGProc *p)
                 else
                     m_secretkey.setComment(QString());
                 m_secretkey.setName(kname);
+            } else if ((lsp.at(0) == "fpr") && (items >= 10)) {
+                QString fingervalue = lsp.at(9);
+
+                m_secretkey.setFingerprint(fingervalue);
             }
     }
 }
@@ -1006,286 +1075,9 @@ void KgpgInterface::signKeyOpenConsole()
     emit signKeyFinished(2, m_keyid, this);
 }
 
-void KgpgInterface::keyExpire(const QString &keyid, const QDate &date)
-{
-    m_partialline.clear();
-    m_ispartial = false;
-    log.clear();
-    m_success = 0;
-    step = 3;
-
-    if (date.isNull())
-        expirationDelay = 0;
-    else
-        expirationDelay = QDate::currentDate().daysTo(date);
-
-	m_workProcess = new KProcess(this);
-	m_workProcess->setOutputChannelMode(KProcess::OnlyStdoutChannel);
-	*m_workProcess << KGpgSettings::gpgBinaryPath();
-	*m_workProcess << "--no-secmem-warning" << "--no-tty" << "--status-fd=1" << "--command-fd=0";
-	*m_workProcess << "--edit-key" << keyid << "expire";
-
-	kDebug(2100) << "Change expiration of the key" << keyid << "to" << expirationDelay << "days";
-	connect(m_workProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(keyExpireProcess()));
-	connect(m_workProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(keyExpireFin()));
-
-	m_workProcess->start();
-}
-
-void KgpgInterface::keyExpireProcess()
-{
-        QString buffer = m_partialline + m_workProcess->readAllStandardOutput();
-
-        while (buffer.contains('\n')) {
-            int pos = buffer.indexOf('\n');
-            QString line = buffer.left(pos);
-            buffer.remove(0, pos + 1);
-
-            if (!line.startsWith("[GNUPG:]"))
-                log += line + '\n';
-            else
-            if (m_success == 3)
-            {
-                if (line.contains("GET_" ))
-                    m_workProcess->write("quit\n");
-                return;
-            }
-            else
-            if (line.contains("USERID_HINT"))
-                updateIDs(line);
-            else
-            if (line.contains("GOOD_PASSPHRASE"))
-            {
-                m_success = 2;
-            }
-            else
-            if (line.contains("keygen.valid"))
-                m_workProcess->write(QString::number(expirationDelay).toAscii() + '\n');
-            else
-            if (line.contains("passphrase.enter"))
-            {
-                QString passdlgmessage;
-                if (step < 3)
-                    passdlgmessage = i18n("<p><b>Bad passphrase</b>. You have %1 tries left.</p>", step);
-                passdlgmessage += i18n("Enter passphrase for <b>%1</b>", checkForUtf8bis(userIDs));
-
-                if (sendPassphrase(passdlgmessage, m_workProcess, false))
-                {
-                    m_success = 3;  // aborted by user mode
-                    m_workProcess->write("quit\n");
-                    return;
-                }
-                --step;
-            }
-            else
-            if ((m_success == 2) && line.contains("keyedit.prompt"))
-                m_workProcess->write("save\n");
-            else
-            if ((m_success == 2) && line.contains("keyedit.save.okay"))
-                m_workProcess->write("YES\n");
-            else
-            if (line.contains("BAD_PASSPHRASE"))
-            {
-                m_success = 1; // bad passphrase
-                m_workProcess->write("quit\n");
-            }
-            else
-            if (line.contains("GET_")) // gpg asks for something unusal, turn to konsole mode
-            {
-                if (m_success != 1)
-                    m_success = 4; // switching to console mode
-                m_workProcess->write("quit\n");
-            }
-        }
-
-}
-
-void KgpgInterface::keyExpireFin()
-{
-    m_workProcess->deleteLater();
-    if (m_success < 4)
-        emit keyExpireFinished(m_success, this); // signature successful or bad passphrase
-    else
-    {
-        KgpgDetailedConsole *q = new KgpgDetailedConsole(0, i18n("<qt><b>Changing expiration failed.</b><br />"
-                                    "Do you want to try changing the key expiration in console mode?</qt>"),output);
-        if (q->exec() == QDialog::Accepted)
-            KMessageBox::sorry(0, i18n("work in progress..."));
-        else
-            emit keyExpireFinished(3, this);
-    }
-}
-
-void KgpgInterface::changePass(const QString &keyid)
-{
-    m_partialline.clear();
-    m_ispartial = false;
-    m_success = 1;
-    step = 3;
-
-	m_workProcess = new KProcess(this);
-	m_workProcess->setOutputChannelMode(KProcess::OnlyStdoutChannel);
-	*m_workProcess << KGpgSettings::gpgBinaryPath();
-	*m_workProcess << "--no-secmem-warning" << "--no-tty" << "--status-fd=1" << "--command-fd=0";
-	*m_workProcess << "--edit-key" << keyid << "passwd";
-
-	kDebug(2100) << "Change passphrase of the key" << keyid;
-	connect(m_workProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(changePassProcess()));
-	connect(m_workProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(changePassFin()));
-
-	m_workProcess->start();
-}
-
-void KgpgInterface::changePassProcess()
-{
-        QString buffer = m_partialline + m_workProcess->readAllStandardOutput();
-
-        while (buffer.contains('\n')) {
-            int pos = buffer.indexOf('\n');
-            QString line = buffer.left(pos);
-            buffer.remove(0, pos + 1);
-
-            if (line.contains("USERID_HINT"))
-                updateIDs(line);
-            else
-            if ((m_success == 4) && line.contains("keyedit.prompt"))
-            {
-                m_success = 2;
-                m_workProcess->write("save\n");
-            }
-            else
-            if (line.contains("GOOD_PASSPHRASE"))
-                m_success = 4;
-            else
-            if (line.contains("passphrase.enter"))
-            {
-                if (userIDs.isEmpty())
-                    userIDs = i18n("[No user id found]");
-                userIDs.replace('<', "&lt;");
-
-                if (m_success == 1)
-                {
-                    QString passdlgmessage;
-                    if (step < 3)
-                        passdlgmessage = i18n("<p><b>Bad passphrase</b>. You have %1 tries left.</p>", step);
-                    passdlgmessage += i18n("Enter old passphrase for <b>%1</b>", checkForUtf8bis(userIDs));
-
-                    if (sendPassphrase(passdlgmessage, m_workProcess, false))
-                    {
-                        m_workProcess->deleteLater();
-                        emit changePassFinished(3, this);
-                        return;
-                    }
-                    --step;
-                }
-                else
-                if (m_success == 4)
-                {
-                    if (sendPassphrase(i18n("<qt>Enter new passphrase for <b>%1</b><br />If you forget this passphrase all your encrypted files and messages will be inaccessible<br /></qt>", userIDs), m_workProcess))
-                    {
-                        m_workProcess->deleteLater();
-                        emit changePassFinished(3, this);
-                        return;
-                    }
-                }
-            }
-            else
-            if (line.contains("GET_")) // gpg asks for something unusal, turn to konsole mode
-            {
-                m_workProcess->write("quit\n");
-            }
-    }
-}
-
-void KgpgInterface::changePassFin()
-{
-    m_workProcess->deleteLater();
-    emit changePassFinished(m_success, this);
-}
-
-void
-KgpgInterface::changeTrust(const QString &keyid, const KgpgCore::KgpgKeyOwnerTrust &keytrust)
-{
-    m_partialline.clear();
-    m_ispartial = false;
-    m_trustvalue = keytrust;
-
-	m_workProcess = new KProcess(this);
-	m_workProcess->setOutputChannelMode(KProcess::OnlyStdoutChannel);
-	*m_workProcess << KGpgSettings::gpgBinaryPath();
-	*m_workProcess << "--no-secmem-warning" << "--no-tty" << "--status-fd=1" << "--command-fd=0";
-	*m_workProcess << "--edit-key" << keyid << "trust";
-
-	kDebug(2100) << "Change trust of the key" << keyid << "to" << keytrust;
-	connect(m_workProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(changeTrustProcess()));
-	connect(m_workProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(changeTrustFin()));
-
-	m_workProcess->start();
-}
-
-void KgpgInterface::changeTrustProcess()
-{
-        QString buffer = m_partialline + m_workProcess->readAllStandardOutput();
-
-        while (buffer.contains('\n')) {
-            int pos = buffer.indexOf('\n');
-            QString line = buffer.left(pos);
-            buffer.remove(0, pos + 1);
-
-            if (line.contains("edit_ownertrust.set_ultimate.okay"))
-                m_workProcess->write("YES\n");
-            else
-            if (line.contains("edit_ownertrust.value"))
-                m_workProcess->write(QString::number(m_trustvalue).toAscii() + '\n');
-            else
-            if (line.contains("keyedit.prompt"))
-            {
-                m_workProcess->write(QByteArray("save\n"));
-            }
-            else
-            if (line.contains("GET_")) // gpg asks for something unusal
-            {
-                m_workProcess->write(QByteArray("quit\n"));
-            }
-    }
-}
-
-void KgpgInterface::changeTrustFin()
-{
-    m_workProcess->deleteLater();
-    emit changeTrustFinished(this);
-}
-
-void KgpgInterface::changeDisable(const QString &keyid, const bool &ison)
-{
-    m_partialline.clear();
-    m_ispartial = false;
-
-    editprocess = new KProcess(this);
-    *editprocess << KGpgSettings::gpgBinaryPath() << "--no-tty" << "--no-greeting" << "--edit-key" << keyid;
-
-    if (ison)
-        *editprocess << "disable";
-    else
-        *editprocess << "enable";
-
-    *editprocess << "save";
-
-    kDebug(2100) << "Change disable of the key" << keyid << "to" << ison;
-    connect(editprocess, SIGNAL(finished(int)), this, SLOT(changeDisableFin(int)));
-    editprocess->start();
-}
-
-void KgpgInterface::changeDisableFin(int res)
-{
-    editprocess->deleteLater();
-    editprocess = 0;
-    emit changeDisableFinished(this, res);
-}
-
 QPixmap KgpgInterface::loadPhoto(const QString &keyid, const QString &uid, const bool &block)
 {
-#ifdef Q_OS_WIN32
+#ifdef Q_OS_WIN32	//krazy:exclude=cpp
 	QString pgpgoutput("cmd /C \"echo %I\"");
 #else
 	QString pgpgoutput("echo %I");
@@ -1327,145 +1119,6 @@ void KgpgInterface::loadPhotoFin(int exitCode)
 	emit loadPhotoFinished(m_pixmap, this);
 }
 
-void KgpgInterface::addPhoto(const QString &keyid, const QString &imagepath)
-{
-	photoUrl = imagepath;
-	m_success = 0;
-	step = 3;
-
-	GPGProc *process = new GPGProc(this);
-	*process << "--status-fd=1" << "--command-fd=0" << "--edit-key" << keyid << "addphoto";
-
-	kDebug(2100) << "Add the photo" << imagepath << "to the key" << keyid;
-	connect(process, SIGNAL(readReady(GPGProc *)), this, SLOT(addPhotoProcess(GPGProc *)));
-	connect(process, SIGNAL(processExited(GPGProc *)), this, SLOT(addPhotoFin(GPGProc *)));
-	process->start();
-}
-
-void KgpgInterface::addPhotoProcess(GPGProc *p)
-{
-    QString line;
-
-    while (p->readln(line, true) >= 0) {
-
-            if (line.contains("USERID_HINT"))
-                updateIDs(line);
-            else
-            if (line.contains("BAD_PASSPHRASE"))
-                m_success = 1;
-            else
-            if (line.contains("GOOD_PASSPHRASE"))
-                m_success = 2;
-            if (line.contains("photoid.jpeg.add"))
-                p->write(photoUrl.toAscii() + '\n');
-            else
-            if (line.contains("photoid.jpeg.size"))
-            {
-                if (KMessageBox::questionYesNo(0, i18n("This image is very large. Use it anyway?"), QString(), KGuiItem(i18n("Use Anyway")), KGuiItem(i18n("Do Not Use"))) == KMessageBox::Yes)
-                    p->write("Yes\n");
-                else
-                {
-                    p->deleteLater();
-                    emit addPhotoFinished(3, this);
-                    return;
-                }
-            }
-            else
-            if (line.contains("passphrase.enter"))
-            {
-                QString passdlgmessage;
-                if (step < 3)
-                    passdlgmessage = i18n("<p><b>Bad passphrase</b>. You have %1 tries left.</p>", step);
-                passdlgmessage += i18n("Enter passphrase for <b>%1</b>", checkForUtf8bis(userIDs));
-
-                if (sendPassphrase(passdlgmessage, p, false))
-                {
-                    p->deleteLater();
-                    emit addPhotoFinished(3, this);
-                    return;
-                }
-
-                step--;
-            }
-            else
-            if ((m_success == 2) && (line.contains("keyedit.prompt")))
-                p->write("save\n");
-            else
-            if ((line.contains("GET_"))) // gpg asks for something unusal, turn to konsole mode
-            {
-                p->write("quit\n");
-            }
-    }
-}
-
-void KgpgInterface::addPhotoFin(GPGProc *p)
-{
-    p->deleteLater();
-    emit addPhotoFinished(m_success, this);
-}
-
-void KgpgInterface::deletePhoto(const QString &keyid, const QString &uid)
-{
-    m_success = 0;
-    step = 3;
-
-    GPGProc *process = new GPGProc(this);
-    *process << "--status-fd=1" << "--command-fd=0" << "--edit-key" << keyid << "uid" << uid << "deluid";
-
-    kDebug(2100) << "Delete a photo from the key" << keyid;
-    connect(process, SIGNAL(readReady(GPGProc *)), this, SLOT(deletePhotoProcess(GPGProc *)));
-    connect(process, SIGNAL(processExited(GPGProc *)), this, SLOT(deletePhotoFin(GPGProc *)));
-    process->start();
-}
-
-void KgpgInterface::deletePhotoProcess(GPGProc *p)
-{
-    QString line;
-
-    while (p->readln(line, true) >= 0) {
-            if (line.contains("USERID_HINT"))
-                updateIDs(line);
-            else
-            if (line.contains("BAD_PASSPHRASE"))
-                m_success = 1;
-            else
-            if (line.contains("GOOD_PASSPHRASE"))
-                m_success = 2;
-            else
-            if (line.contains("keyedit.remove.uid.okay"))
-                p->write("YES\n");
-            else
-            if (line.contains("passphrase.enter"))
-            {
-                QString passdlgmessage;
-                if (step < 3)
-                    passdlgmessage = i18n("<p><b>Bad passphrase</b>. You have %1 tries left.</p>", step);
-                passdlgmessage += i18n("Enter passphrase for <b>%1</b>", checkForUtf8bis(userIDs));
-
-                if (sendPassphrase(passdlgmessage, p, false))
-                {
-                    p->deleteLater();
-                    emit deletePhotoFinished(3, this);
-                    return;
-                }
-            }
-            else
-            if (line.contains("keyedit.prompt"))
-                p->write("save\n");
-            else
-            if (line.contains("GET_")) // gpg asks for something unusal, turn to konsole mode
-            {
-                p->write("quit\n");
-            }
-    }
-}
-
-void KgpgInterface::deletePhotoFin(GPGProc *p)
-{
-    p->deleteLater();
-    emit deletePhotoFinished(m_success, this);
-}
-
 void KgpgInterface::importKey(const QString &keystr)
 {
     message.clear();
@@ -1476,7 +1129,7 @@ void KgpgInterface::importKey(const QString &keystr)
     *process << "--allow-secret-key-import";
 
     connect(process, SIGNAL(readReady(GPGProc *)), this, SLOT(importKeyProcess(GPGProc *)));
-    connect(process, SIGNAL(processExited(GPGProc *)), this, SLOT(importKeyFinished(GPGProc *)));
+    connect(process, SIGNAL(processExited(GPGProc *)), SLOT(slotImportKeyFinished(GPGProc *)));
     process->start();
 
     process->write(keystr.toAscii() + '\n');
@@ -1495,7 +1148,7 @@ void KgpgInterface::importKey(const KUrl &url)
 
 	if ( url.isLocalFile() ) {
 		*process << url.path();
-		connect(process, SIGNAL(processExited(GPGProc *)), this, SLOT(importKeyFinished(GPGProc *)));
+		connect(process, SIGNAL(processExited(GPGProc *)), SLOT(slotImportKeyFinished(GPGProc *)));
 	} else {
 		if (KIO::NetAccess::download(url, m_tempkeyfile, 0)) {
 			*process << m_tempkeyfile;
@@ -1513,7 +1166,7 @@ void KgpgInterface::importKey(const KUrl &url)
 void KgpgInterface::importURLover(GPGProc *p)
 {
     KIO::NetAccess::removeTempFile(m_tempkeyfile);
-    emit importKeyFinished(p);
+    slotImportKeyFinished(p);
 }
 
 void KgpgInterface::importKeyProcess(GPGProc *p)
@@ -1526,7 +1179,7 @@ void KgpgInterface::importKeyProcess(GPGProc *p)
     }
 }
 
-void KgpgInterface::importKeyFinished(GPGProc *p)
+void KgpgInterface::slotImportKeyFinished(GPGProc *p)
 {
     p->deleteLater();
 
@@ -1588,231 +1241,17 @@ void KgpgInterface::importKeyFinished(GPGProc *p)
                                   "Please note that imported secret keys are not trusted by default.<br />"
                                   "To fully use this secret key for signing and encryption, you must edit the key (double click on it) and set its trust to Full or Ultimate.</qt>");
 
-        emit importKeyFinished(importedKeysIds);
-   }
-    else
+        emit importKeyFinished(this, importedKeysIds);
+   } else {
         resultMessage = i18n("No key imported... \nCheck detailed log for more infos");
+        emit importKeyFinished(this, QStringList());
+   }
 
     // TODO : should be deleted. KgpgInterface should not show any dialog (but password).
     // When a message should be shown, it should be passed by parameter in a SIGNAL.
     (void) new KgpgDetailedInfo(0, resultMessage, message, importedKeys);
 }
 
-void KgpgInterface::addUid(const QString &keyid, const QString &name, const QString &email, const QString &comment)
-{
-	step = 3;
-	m_success = 0;
-	// why the heck does QValidator don't take const arguments?
-	QString Email = email;
-
-	int pos = 0;
-	if (!email.isEmpty() && (EmailValidator().validate(Email, pos) == QValidator::Invalid)) {
-		emit addUidFinished(4, this);
-		return;
-	}
-
-	uidName = name;
-	uidComment = comment;
-	uidEmail = email;
-
-	GPGProc *process = new GPGProc(this);
-	*process << "--status-fd=1" << "--command-fd=0" << "--edit-key" << keyid << "adduid";
-
-	connect(process, SIGNAL(readReady(GPGProc *)), this, SLOT(addUidProcess(GPGProc *)));
-	connect(process, SIGNAL(processExited(GPGProc *)), this, SLOT(addUidFin(GPGProc *)));
-	process->start();
-}
-
-void KgpgInterface::addUidProcess(GPGProc *p)
-{
-    QString line;
-
-    while (p->readln(line, true) >= 0) {
-            if (line.contains("USERID_HINT"))
-                updateIDs(line);
-            else
-            if (line.contains("BAD_PASSPHRASE"))
-                m_success = 1;
-            else
-            if (line.contains("GOOD_PASSPHRASE"))
-                m_success = 2;
-            else
-            if (line.contains("keygen.name"))
-                p->write(uidName.toAscii() + '\n');
-            else
-            if (line.contains("keygen.email"))
-                p->write(uidEmail.toAscii() + '\n');
-            else
-            if (line.contains("keygen.comment"))
-                p->write(uidComment.toAscii() + '\n');
-            else
-            if (line.contains("passphrase.enter"))
-            {
-                QString passdlgmessage;
-                if (step < 3)
-                    passdlgmessage = i18n("<p><b>Bad passphrase</b>. You have %1 tries left.</p>", step);
-                passdlgmessage += i18n("Enter passphrase for <b>%1</b>", checkForUtf8bis(userIDs));
-
-                if (sendPassphrase(passdlgmessage, p, false))
-                {
-                    p->deleteLater();
-                    emit addUidFinished(3, this);
-                    return;
-                }
-                step--;
-            }
-            else
-            if (line.contains("keyedit.prompt"))
-                p->write("save\n");
-            else
-            if (line.contains("GET_")) // gpg asks for something unusal, turn to konsole mode
-            {
-                p->write("quit\n");
-            }
-    }
-}
-
-void KgpgInterface::addUidFin(GPGProc *p)
-{
-    p->deleteLater();
-    emit addUidFinished(m_success, this);
-}
-
-void
-KgpgInterface::generateKey(const QString &keyname, const QString &keyemail, const QString &keycomment, const KgpgCore::KgpgKeyAlgo &keyalgo, const uint &keysize, const uint &keyexp, const uint &keyexpnumber)
-{
-    step = 3;
-    m_success = 0;
-    QString Email = keyemail;
-
-	int pos = 0;
-	if (!keyemail.isEmpty() && (EmailValidator().validate(Email, pos) == QValidator::Invalid)) {
-		emit generateKeyFinished(4, this, keyname, keyemail, QString());
-		return;
-	}
-
-    m_newfingerprint.clear();
-    m_keyname = keyname;
-    m_keyemail = keyemail;
-    m_keycomment = keycomment;
-    m_keyalgo = keyalgo;
-    m_keysize = keysize;
-    m_keyexp = keyexp;
-    m_keyexpnumber = keyexpnumber;
-
-    GPGProc *process = new GPGProc(this);
-    *process << "--command-fd=0" << "--status-fd=1" << "--no-verbose" << "--no-greeting";
-    *process << "--gen-key";
-
-    kDebug(2100) << "Generate a new key-pair";
-    connect(process, SIGNAL(readReady(GPGProc *)), this, SLOT(generateKeyProcess(GPGProc *)));
-    connect(process, SIGNAL(processExited(GPGProc *)), this, SLOT(generateKeyFin(GPGProc *)));
-    process->start();
-}
-
-void KgpgInterface::generateKeyProcess(GPGProc *p)
-{
-    QString line;
-
-    while (p->readln(line, true) >= 0) {
-
-            if (line.contains("BAD_PASSPHRASE"))
-                m_success = 1;
-            else
-            if ((m_success == 5) && line.contains("PROGRESS"))
-            {
-                m_success = 0;
-                emit generateKeyStarted(this);
-            }
-            else
-            if (line.contains("keygen.algo"))
-            {
-                if (m_keyalgo == ALGO_RSA)
-                    p->write("5\n");
-                else
-                    p->write("1\n");
-            }
-            else
-            if (line.contains("keygen.size"))
-                p->write(QString::number(m_keysize).toAscii() + '\n');
-            else
-            if (line.contains("keygen.valid"))
-            {
-                QString output;
-                if (m_keyexp != 0)
-                {
-                    output = QString::number(m_keyexpnumber);
-                    if (m_keyexp == 1)
-                        output.append("d");
-                    if (m_keyexp == 2)
-                        output.append("w");
-                    if (m_keyexp == 3)
-                        output.append("m");
-                    if (m_keyexp == 4)
-                        output.append("y");
-                }
-                else
-                  output = QString("0");
-
-                p->write(output.toAscii() + '\n');
-            }
-            else
-            if (line.contains("keygen.name")) {
-		if (m_success == 10) {
-			p->kill();
-		} else {
-			m_success = 10;
-			p->write(m_keyname.toAscii() + '\n');
-		}
-            } else
-            if (line.contains("keygen.email"))
-                p->write(m_keyemail.toAscii() + '\n');
-            else
-            if (line.contains("keygen.comment"))
-                p->write(m_keycomment.toAscii() + '\n');
-            else
-            if (line.contains("passphrase.enter"))
-            {
-                QString keyid;
-                if (!m_keyemail.isEmpty())
-                    keyid = m_keyname + " <" + m_keyemail + '>';
-                else
-                    keyid = m_keyname;
-                QString passdlgmessage = i18n("<p><b>Enter passphrase for %1</b>:<br />Passphrase should include non alphanumeric characters and random sequences</p>", keyid);
-                if (sendPassphrase(passdlgmessage, p, true))
-                {
-                    p->deleteLater();
-                    emit generateKeyFinished(3, this, m_keyname, m_keyemail, QString());
-                    return;
-                }
-                step--;
-                m_success = 5;
-            }
-            else
-            if (line.contains("GOOD_PASSPHRASE"))
-		m_success = 5;
-            else
-            if (line.contains("KEY_CREATED"))
-            {
-                m_newfingerprint = line.right(40);
-                m_success = 2;
-            }
-            else
-            if (line.contains("GET_"))
-            {
-                p->write("quit\n");
-            } else if (line.contains("NEED_PASSPHRASE")) {
-		m_success = 3;
-            }
-    }
-}
-
-void KgpgInterface::generateKeyFin(GPGProc *p)
-{
-    p->deleteLater();
-    emit generateKeyFinished(m_success, this, m_keyname, m_keyemail, m_newfingerprint);
-}
-
 void KgpgInterface::downloadKeys(const QStringList &keys, const QString &keyserver, const bool &refresh, const QString &proxy)
 {
     m_downloadkeys.clear();
@@ -1902,7 +1341,7 @@ void KgpgInterface::downloadKeysFin(GPGProc *p)
     for(int i = 0; i < nbs.count(); ++i)
     {
         result.append(nbs[i].toInt());
-        if (!key && result[i] != 0)
+        if (result[i] != 0)
             key = true;
     }
 
