@@ -62,6 +62,7 @@
 #include <assert.h>
 #include <ktoolbar.h>
 #include <kicon.h>
+#include <KAction>
 
 KWalletEditor::KWalletEditor(const QString& wallet, bool isPath, QWidget *parent, const char *name)
 : KXmlGuiWindow(parent), _walletName(wallet), _nonLocal(isPath) {
@@ -246,7 +247,7 @@ void KWalletEditor::walletClosed() {
 
 
 void KWalletEditor::updateFolderList(bool checkEntries) {
-	QStringList fl = _w->folderList();
+	const QStringList fl = _w->folderList();
 	Q3PtrStack<Q3ListViewItem> trash;
 
 	for (Q3ListViewItem *i = _entryList->firstChild(); i; i = i->nextSibling()) {
@@ -262,7 +263,7 @@ void KWalletEditor::updateFolderList(bool checkEntries) {
 	trash.setAutoDelete(true);
 	trash.clear();
 
-	for (QStringList::Iterator i = fl.begin(); i != fl.end(); ++i) {
+	for (QStringList::const_iterator i = fl.begin(); i != fl.end(); ++i) {
 		if (_entryList->existsFolder(*i)) {
 			if (checkEntries) {
 				updateEntries(*i);
@@ -271,7 +272,7 @@ void KWalletEditor::updateFolderList(bool checkEntries) {
 		}
 
 		_w->setFolder(*i);
-		QStringList entries = _w->entryList();
+		const QStringList entries = _w->entryList();
 		KWalletFolderItem *item = new KWalletFolderItem(_w,_entryList,
 			*i, entries.count());
 
@@ -280,7 +281,7 @@ void KWalletEditor::updateFolderList(bool checkEntries) {
 		KWalletContainerItem *bi = new KWalletContainerItem(item, i18n("Binary Data"),KWallet::Wallet::Stream);
 		KWalletContainerItem *ui = new KWalletContainerItem(item, i18n("Unknown"),KWallet::Wallet::Unknown);
 
-		for (QStringList::Iterator j = entries.begin(); j != entries.end(); ++j) {
+		for (QStringList::const_iterator j = entries.begin(); j != entries.end(); ++j) {
 			switch (_w->entryType(*j)) {
 				case KWallet::Wallet::Password:
 					new KWalletEntryItem(_w, pi, *j);
@@ -355,7 +356,7 @@ void KWalletEditor::createFolder() {
 				if (rc == KMessageBox::Yes) {
 					continue;
 				}
-				n = QString();
+				n.clear();
 			}
 			break;
 		} while (true);
@@ -541,7 +542,7 @@ void KWalletEditor::updateEntries(const QString& folder) {
 	Q3PtrStack<Q3ListViewItem> trash;
 
 	_w->setFolder(folder);
-	QStringList entries = _w->entryList();
+	const QStringList entries = _w->entryList();
 
 	KWalletFolderItem *fi = _entryList->getFolder(folder);
 
@@ -595,7 +596,7 @@ void KWalletEditor::updateEntries(const QString& folder) {
 	trash.clear();
 
 	// Add new entries
-	for (QStringList::Iterator i = entries.begin(); i != entries.end(); ++i) {
+	for (QStringList::const_iterator i = entries.begin(); i != entries.end(); ++i) {
 		if (fi->contains(*i)){
 			continue;
 		}
@@ -689,7 +690,7 @@ void KWalletEditor::newEntry() {
 			if (rc == KMessageBox::Yes) {
 				continue;
 			}
-			n = QString();
+			n.clear();
 		}
 		break;
 	} while (true);
@@ -1084,14 +1085,14 @@ void KWalletEditor::exportXML() {
 	KTemporaryFile tf;
 	tf.open();
 	QTextStream ts(&tf);
-	QStringList fl = _w->folderList();
+	const QStringList fl = _w->folderList();
 
 	ts << "<wallet name=\"" << _walletName << "\">" << endl;
-	for (QStringList::Iterator i = fl.begin(); i != fl.end(); ++i) {
+	for (QStringList::const_iterator i = fl.constBegin(); i != fl.constEnd(); ++i) {
 		ts << "  <folder name=\"" << *i << "\">" << endl;
 		_w->setFolder(*i);
 		QStringList entries = _w->entryList();
-		for (QStringList::Iterator j = entries.begin(); j != entries.end(); ++j) {
+		for (QStringList::const_iterator j = entries.constBegin(); j != entries.constEnd(); ++j) {
 			switch (_w->entryType(*j)) {
 				case KWallet::Wallet::Password:
 					{
@@ -1119,7 +1120,7 @@ void KWalletEditor::exportXML() {
 						QMap<QString,QString> map;
 						if (_w->readMap(*j, map) == 0) {
 							ts << "    <map name=\"" << Qt::escape(*j) << "\">" << endl;
-							for (QMap<QString,QString>::ConstIterator k = map.begin(); k != map.end(); ++k) {
+							for (QMap<QString,QString>::ConstIterator k = map.constBegin(); k != map.constEnd(); ++k) {
 								ts << "      <mapentry name=\"" << Qt::escape(k.key()) << "\">" << Qt::escape(k.value()) << "</mapentry>" << endl;
 							}
 							ts << "    </map>" << endl;
