@@ -113,7 +113,9 @@ StringsExtractView::StringsExtractView( StringsExtractTool *tool, QWidget *paren
     mContainedStringTableView->setSelectionMode( QAbstractItemView::ExtendedSelection );
     mContainedStringTableView->setSortingEnabled( true );
     mContainedStringTableView->setFont( KGlobalSettings::fixedFont() );
-    mContainedStringTableView->header()->setFont( font() );
+    QHeaderView* header = mContainedStringTableView->header();
+    header->setFont( font() );
+    header->setResizeMode( QHeaderView::ResizeToContents );
     mContainedStringTableView->setModel( mSortFilterProxyModel );
     mContainedStringTableView->sortByColumn( ContainedStringTableModel::OffsetColumnId, Qt::AscendingOrder );
     connect( mContainedStringTableView, SIGNAL(doubleClicked( const QModelIndex& )),
@@ -209,7 +211,9 @@ void StringsExtractView::onStringSelectionChanged()
 {
     const QItemSelectionModel *selectionModel = mContainedStringTableView->selectionModel();
 
-    const bool hasSelection = selectionModel->hasSelection();
+    // TODO: selectionModel->selectedIndexes() is a expensive operation,
+    // but with Qt 4.4.3 hasSelection() has the flaw to return true with a current index
+    const bool hasSelection = !selectionModel->selectedIndexes().isEmpty();
     mCopyButton->setEnabled( hasSelection );
 
     const bool stringSelected = selectionModel->isSelected( selectionModel->currentIndex() );
@@ -224,5 +228,3 @@ void StringsExtractView::onStringDoubleClicked( const QModelIndex &index )
 }
 
 StringsExtractView::~StringsExtractView() {}
-
-#include "stringsextractview.moc"
